@@ -449,3 +449,65 @@ def dev_show_diff(filename):
         return display_code(filename)
     else:
         print_run_cmd("git diff " + filename)
+
+
+def move_single_ipynb(file_ipynb):
+    # file_ipynb = "20230306.ipynb"
+    import os
+
+    if os.path.isfile(file_ipynb):
+        assert file_ipynb.endswith(".ipynb")
+        assert len(file_ipynb) == len("yyyyMMdd.ipynb")
+        import datetime
+
+        current_date = datetime.datetime.now()
+        dir_year = file_ipynb[0:4]
+        dir_month = file_ipynb[4:6]
+        assert int(dir_year) <= current_date.year
+        assert int(dir_year) + 1 >= current_date.year
+        print(int(dir_month))
+        assert int(dir_month) <= 12
+        assert int(dir_month) >= 1
+
+        dir_ipynb = dir_year + "/" + dir_month
+        if os.path.isdir(dir_ipynb) == False:
+            os.makedirs(dir_ipynb)
+        cmd_run = "git mv " + file_ipynb + " " + dir_ipynb
+        print(cmd_run)
+        cmd_ret = util.print_run_cmd(cmd_run)
+    else:
+        print("Can not find %s" % file_ipynb)
+
+
+def git_add_ipynb(file_ipynb):
+    cmd_run = "git add " + file_ipynb
+    cmd_ret = util.print_run_cmd(cmd_run)
+
+
+def endswith(*endstring):
+    ends = endstring
+
+    def run(s):
+        f = map(s.endswith, ends)
+        if True in f:
+            return s
+
+    return run
+
+
+def dev_clean_ipynb():
+    import os
+
+    list_file = os.listdir(".")
+    a = endswith(".ipynb")  # , '.txt','.py', '.md')
+    f_file = filter(a, list_file)
+    f_sort = sorted(f_file)
+    idx = 0
+    idx_limit = len(f_sort)
+    for i in f_sort:
+        idx = idx + 1
+        git_add_ipynb(i)
+        if idx < idx_limit:
+            move_single_ipynb(i)
+        else:
+            print("Ignore %s" % i)
